Module health

Module health 

Structs

HealthConfig
Configuration for health monitoring
HealthMonitor
Health monitor for tracking stream status and connectivity
SlotTracker
Tracks the last processed slot for stream resumption after reconnection.

Enums

StreamStatus

Functions

get_slot_hash
Get the slot hash for a specific slot (if available) This can be called from computed fields
init_global_slot_tracker
Initialize the global slot tracker