pub fn auth_failure_event(
error_code: &AuthErrorCode,
reason: &str,
) -> SecurityAuditEventExpand description
Helper function to create an auth failure audit event
pub fn auth_failure_event(
error_code: &AuthErrorCode,
reason: &str,
) -> SecurityAuditEventHelper function to create an auth failure audit event