pub struct WebSocketServer { /* private fields */ }Implementations
Sourceimpl WebSocketServer
impl WebSocketServer
pub fn new( bind_addr: SocketAddr, bus_manager: BusManager, entity_cache: EntityCache, view_index: Arc<ViewIndex>, ) -> Self
pub fn with_max_clients(self, max_clients: usize) -> Self
pub fn with_auth_plugin(self, auth_plugin: Arc<dyn WebSocketAuthPlugin>) -> Self
pub fn with_usage_emitter( self, usage_emitter: Arc<dyn WebSocketUsageEmitter>, ) -> Self
Sourcepub fn with_rate_limit_config(self, config: RateLimitConfig) -> Self
pub fn with_rate_limit_config(self, config: RateLimitConfig) -> Self
Configure rate limiting for the WebSocket server.
This allows setting global rate limits that apply to all connections, such as maximum connections per IP, timeouts, and rate windows. Per-subject limits are controlled via AuthContext.Limits from the auth token.
pub async fn start(self) -> Result<()>