Structs
- Allow
AllAuth Plugin - Development-only plugin that allows all connections
- Auth
Context - Auth context extracted from a verified token
- Auth
Deny - Enhanced authentication denial with structured error information
- Auth
Error Details - Structured error details for machine-readable error handling
- Auth
Metrics - Authentication metrics for observability
- Auth
Metrics Snapshot - Serializable snapshot of auth metrics
- Channel
Audit Logger - Channel-based audit logger for async event streaming
- Connection
Auth Request - Error
Response - JSON-serializable error response for clients
- Multi
KeyVerifier - Multi-key verifier supporting graceful key rotation
- Multi
KeyVerifier Builder - Builder for constructing a MultiKeyVerifier with rotation support
- NoOp
Audit Logger - No-op audit logger for development/testing
- Rotation
Key - A key with its metadata for rotation
- Security
Audit Event - Security audit event
- Signed
Session Auth Plugin - Static
Token Auth Plugin
Enums
- Audit
Event - Security audit event types
- Audit
Severity - Security audit event severity levels
- Auth
Decision - Authentication decision with optional auth context
- Auth
Error Code - Machine-readable error codes for authentication failures
- Retry
Policy - Retry policy for authentication errors
Traits
- Auth
Metrics Collector - Trait for collecting auth metrics
- Security
Audit Logger - Trait for security audit loggers
- WebSocket
Auth Plugin
Functions
- auth_
failure_ event - Helper function to create an auth failure audit event
- auth_
success_ event - Helper function to create an auth success audit event
- rate_
limit_ event - Helper function to create a rate limit exceeded audit event